FallibleStreamElement

Enum FallibleStreamElement 

pub enum FallibleStreamElement {
    Ok(XmppStreamElement),
    Err(StreamElementError),
}
Wrapper type to catch parse errors of XmppStreamElement items.

Variants



Ok(XmppStreamElement)

Parsing succeeded.



Err(StreamElementError)

Parsing failed.

Implementations

Source

impl FallibleStreamElement

pub fn into_read_error(self) -> Result<XmppStreamElement, ReadError>

Convert the contained error condition (if any) to a ReadError.

This can be used in places where you do not care to handle the various error conditions separately.