pub enum StreamElementError {
InvalidStanza {
ns: Namespace<'static>,
name: PartialStanza,
header: RawStanzaHeader,
error: Error,
},
InvalidNonza {
qname: QName,
error: Error,
},
}Expand description
Error condition arising from failing to convert a stream-level element
into a xmpp_parsers struct.
Variants
InvalidStanza
Failed to convert an expected <iq/>, <presence/> or <message/>
element into a struct.
Fields

name: PartialStanzaName of the element.

header: RawStanzaHeaderHeader attributes of the invalid stanza.
InvalidNonza
Invalid top-level stream element.
This is reported if the element header matched the
XmppStreamElement type, but the payload failed to parse and it was
not a stanza.