pub enum FallibleStreamElement {
Ok(XmppStreamElement),
Err(StreamElementError),
}Expand description
Wrapper type to catch parse errors of XmppStreamElement items.
Variants
Implementations
Sourceimpl FallibleStreamElement
impl FallibleStreamElement
Sourcepub fn into_read_error(self) -> Result<XmppStreamElement, ReadError>
pub fn into_read_error(self) -> Result<XmppStreamElement, ReadError>
Convert the contained error condition (if any) to a ReadError.
This can be used in places where you do not care to handle the various error conditions separately.